import { checkAdminAuth, generateRandomToken } from '@/lib/auth';
import { NextRequest, NextResponse } from 'next/server';

export async function POST(request: NextRequest) {
  try {
    const body = await request.json();
    // Check for admin auth
    const { password } = body;
    const isAuthenticated = await checkAdminAuth(password);
    if (!isAuthenticated) {
      return NextResponse.json(
        { error: 'Unauthorized' },
        { status: 401 }
      );
    }

    // Parse request body
    const count = parseInt(body.count) || 10;

    // Limit the number of tokens that can be generated at once
    if (count < 1 || count > 1000) {
      return NextResponse.json(
        { error: 'Count must be between 1 and 1000' },
        { status: 400 }
      );
    }

    // Generate tokens and URLs
    const baseUrl = process.env.NEXT_PUBLIC_BASE_URL || request.nextUrl.origin;
    const tokens = [];

    for (let i = 0; i < count; i++) {
      const token = await generateRandomToken();
      const voteUrl = `${baseUrl}/vote?token=${encodeURIComponent(token)}`;
      tokens.push({ token, voteUrl });
    }

    // Create CSV content
    const csvHeader = 'Token,Abstimmungslink\n';
    const csvRows = tokens.map(({ token, voteUrl }) => `"${token}","${voteUrl}"`).join('\n');
    const csvContent = csvHeader + csvRows;

    // Return CSV as text response
    return new NextResponse(csvContent, {
      headers: {
        'Content-Type': 'text/csv; charset=utf-8',
        'Content-Disposition': `attachment; filename="abstimmungslinks_${new Date().toISOString().slice(0, 10)}.csv"`,
      },
    });
  } catch (error) {
    console.error('Error generating bulk tokens:', error);
    return NextResponse.json(
      { error: 'Failed to generate tokens' },
      { status: 500 }
    );
  }
}
