import { checkAdminAuth } from '@/lib/auth';
import { resetMemberVotingStatus } from '@/lib/server-auth';
import fs from 'fs';
import { NextResponse } from 'next/server';
import path from 'path';

export async function POST() {
  try {
    // Check for admin auth using JWT cookie
    const isAuthenticated = await checkAdminAuth();
    if (!isAuthenticated) {
      return NextResponse.json(
        { error: 'Unauthorized' },
        { status: 401 }
      );
    }

    // Reset responses.json to an empty array
    const responsesPath = path.join(process.cwd(), 'data', 'responses.json');
    fs.writeFileSync(responsesPath, '[]', 'utf8');

    // Reset used_tokens.json to an empty array
    const usedTokensPath = path.join(process.cwd(), 'data', 'used_tokens.json');
    fs.writeFileSync(usedTokensPath, '[]', 'utf8');

    // Reset member voting status
    resetMemberVotingStatus();

    return NextResponse.json({
      success: true,
      message: 'Abstimmungsdaten wurden zurückgesetzt'
    });

  }
  catch (error) {
    console.error('Error resetting votes:', error);
    return NextResponse.json(
      { error: 'Fehler beim Zurücksetzen der Abstimmungsdaten' },
      { status: 500 }
    );
  }
}
