import { NextRequest, NextResponse } from 'next/server';
import { verifyToken } from '@/lib/server-auth';
import { saveResponse, VoteOption, getVoteOptions } from '@/lib/survey';

export async function POST(request: NextRequest) {
  try {
    // Get the token from the request
    const { token, vote, comment } = await request.json();
    
    if (!token) {
      return NextResponse.json(
        { error: 'Token is required' },
        { status: 400 }
      );
    }
    
    // Get available vote options
    const voteOptions = getVoteOptions();
    const validOptionIds = voteOptions.map(option => option.id);
    
    if (!vote || !validOptionIds.includes(vote)) {
      return NextResponse.json(
        { error: 'Valid vote option is required' },
        { status: 400 }
      );
    }
    
    // Verify the token
    const { valid } = await verifyToken(token);
    
    if (!valid) {
      return NextResponse.json(
        { error: 'Invalid or already used token' },
        { status: 401 }
      );
    }
    
    // Save the response
    const response = saveResponse(vote as VoteOption, comment);
    
    return NextResponse.json({ success: true, response });
  } catch (error) {
    console.error('Error submitting vote:', error);
    return NextResponse.json(
      { error: 'Failed to submit vote' },
      { status: 500 }
    );
  }
}
