import { checkAdminAuth } from '@/lib/auth';
import { getSettings, updateSettings } from '@/lib/server-auth';
import { NextRequest, NextResponse } from 'next/server';

export async function POST(request: NextRequest) {
  try {
    const body = await request.json();
    // Check for admin auth
    const { password } = body;
    const isAuthenticated = await checkAdminAuth(password);
    if (!isAuthenticated) {
      return NextResponse.json(
        { error: 'Unauthorized' },
        { status: 401 }
      );
    }
    // Get current settings
    const settings = getSettings();

    // Toggle the setting
    const newSettings = {
      ...settings,
      memberAuthEnabled: !settings.memberAuthEnabled
    };

    // Update settings
    updateSettings(newSettings);

    return NextResponse.json({
      success: true,
      memberAuthEnabled: newSettings.memberAuthEnabled,
      message: newSettings.memberAuthEnabled
        ? 'Mitgliederanmeldung wurde aktiviert'
        : 'Mitgliederanmeldung wurde deaktiviert'
    });
  } catch (error) {
    console.error('Error toggling member auth:', error);
    return NextResponse.json(
      { error: 'Fehler beim Ändern der Einstellung' },
      { status: 500 }
    );
  }
}
