import { checkAdminAuth } from '@/lib/auth';
import { importMembersFromCSV } from '@/lib/server-auth';
import { NextRequest, NextResponse } from 'next/server';

export async function POST(request: NextRequest) {
  try {
    // Check for admin auth
    const isAuthenticated = await checkAdminAuth();
    if (!isAuthenticated) {
      return NextResponse.json(
        { error: 'Unauthorized' },
        { status: 401 }
      );
    }
    // Get the CSV content from the request
    const formData = await request.formData();
    const file = formData.get('file') as File;

    if (!file) {
      return NextResponse.json(
        { error: 'Keine Datei hochgeladen' },
        { status: 400 }
      );
    }

    // Check file type
    if (!file.name.endsWith('.csv')) {
      return NextResponse.json(
        { error: 'Nur CSV-Dateien werden unterstützt' },
        { status: 400 }
      );
    }

    // Read the file content
    const csvContent = await file.text();

    // Import members from CSV
    const result = importMembersFromCSV(csvContent);

    return NextResponse.json({
      success: true,
      added: result.added,
      skipped: result.skipped,
      message: `${result.added} Mitglieder importiert, ${result.skipped} übersprungen`
    });
  } catch (error) {
    console.error('Error uploading members:', error);
    return NextResponse.json(
      { error: 'Fehler beim Importieren der Mitglieder' },
      { status: 500 }
    );
  }
}
