import type { Metadata } from "next";
import { Geist, Geist_Mono } from "next/font/google";
import Link from "next/link";
import Image from "next/image";
import "./globals.css";

const geistSans = Geist({
  variable: "--font-geist-sans",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "SCHAFWASCHENER SEGELVEREIN CHIEMSEE E.V. RIMSTING - Online Voting System",
  description: "Secure online voting system for SCHAFWASCHENER SEGELVEREIN CHIEMSEE E.V. RIMSTING club members",
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="de">
      <body
        className={`${geistSans.variable} ${geistMono.variable} antialiased`}
      >
        <header className="ssvc-header">
          <div className="ssvc-logo-container">
            <div className="w-24 h-24 relative">
              <div className="absolute inset-0 bg-[#0057a6] flex items-center justify-center text-white font-bold" >
                <Image 
                  src="/ssvc-logo.svg" 
                  alt="SSVC Logo" 
                  width={92} 
                  height={48} 
                  priority
                />
              </div>
            </div>
            <div className="ssvc-logo-text">
              <div className="text-sm font-bold">SCHAFWASCHENER SEGELVEREIN</div>
              <div className="text-sm font-bold">CHIEMSEE E.V.</div>
              <div className="text-sm font-bold">RIMSTING</div>
            </div>
          </div>
        </header>
        <nav className="ssvc-nav">
          <Link href="/">HOME</Link>
          <Link href="/admin">ADMIN</Link>
        </nav>
        <main>
          {children}
        </main>
        <footer className="ssvc-footer">
          <p>© {new Date().getFullYear()} SCHAFWASCHENER SEGELVEREIN CHIEMSEE E.V. RIMSTING. Alle Rechte vorbehalten.</p>
        </footer>
      </body>
    </html>
  );
}
