'use client';

import { useState, useEffect } from 'react';

interface EditableTextProps {
  id: string;
}

interface TextItem {
  id: string;
  content: string;
}

export function EditableText({ id }: EditableTextProps) {
  const [content, setContent] = useState<string>('');
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    const fetchText = async () => {
      try {
        setIsLoading(true);
        const response = await fetch('/api/editable-text');
        
        if (response.ok) {
          const data = await response.json();
          if (data.texts && Array.isArray(data.texts)) {
            const textItem = data.texts.find((text: TextItem) => text.id === id);
            if (textItem) {
              setContent(textItem.content);
            }
          }
        }
      } catch (error) {
        console.error('Error fetching editable text:', error);
      } finally {
        setIsLoading(false);
      }
    };

    fetchText();
  }, [id]);

  if (isLoading) {
    return <div className="animate-pulse bg-gray-200 h-20 w-full"></div>;
  }

  return (
    <div 
      className="editable-text"
      dangerouslySetInnerHTML={{ __html: content }}
    />
  );
}
