'use client';

import { useState } from 'react';
import QuillEditor from '@/components/QuillEditor';

interface TextEditorProps {
    textId: string;
    initialContent: string;
    onSave: (content: string) => void;
    onCancel: () => void;
}

export default function TextEditor({ textId, initialContent, onSave, onCancel }: TextEditorProps) {
    const [editorContent, setEditorContent] = useState(initialContent);
    // No need for loading or error states as parent handles saving

    const getTextTitle = () => {
        switch (textId) {
            case 'welcome-text':
                return 'Willkommenstext';
            case 'current-vote-text':
                return 'Aktuelle Abstimmung Text';
            case 'vote-question':
                return 'Abstimmungsfrage';
            default:
                return 'Text bearbeiten';
        }
    };

    const handleSaveText = () => {
        onSave(editorContent);
    };

    return (
        <div className="container mx-auto px-4 py-8">
            <div className="mb-8">
                <h1 className="text-2xl font-bold text-[#0057a6] mb-4">TEXT BEARBEITEN</h1>

                <div className="ssvc-main-content">
                    <div className="mb-4">
                        <h2 className="text-lg font-medium text-[#0057a6] mb-2">
                            {getTextTitle()}
                        </h2>

                        <div className="mb-4">
                            <QuillEditor
                                value={editorContent}
                                onChange={setEditorContent}
                                placeholder="Enter content here..."
                            />
                        </div>

                        <div className="flex gap-2">
                            <button
                                onClick={handleSaveText}
                                className="ssvc-button flex-1"
                            >
                                Speichern
                            </button>

                            <button
                                onClick={onCancel}
                                className="flex-1 bg-gray-600 hover:bg-gray-700 text-white font-medium py-2 px-4 transition-colors duration-300"
                            >
                                Abbrechen
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    );
}
