'use client';

interface EditableText {
    id: string;
    content: string;
}

interface TextEditorManagerProps {
    editableTexts: EditableText[];
    onEditText: (textId: string) => void;
}

export default function TextEditorManager({ editableTexts, onEditText }: TextEditorManagerProps) {
    // Helper function to get a human-readable title for each text ID
    const getTextTitle = (textId: string) => {
        switch (textId) {
            case 'welcome-text':
                return 'Willkommenstext bearbeiten';
            case 'current-vote-text':
                return 'Aktuelle Abstimmung Text bearbeiten';
            case 'vote-question':
                return 'Abstimmungsfrage bearbeiten';
            default:
                return `${textId} bearbeiten`;
        }
    };

    // Filter out vote-options as it's handled separately
    const textItems = editableTexts.filter(text => text.id !== 'vote-options');

    return (
        <div className="mb-6">
            <h2 className="text-xl font-bold text-[#0057a6] mb-4">Texte bearbeiten</h2>

            <div className="space-y-3">
                {textItems.map(text => (
                    <button
                        key={text.id}
                        onClick={() => onEditText(text.id)}
                        className="w-full text-left p-3 border border-gray-200 hover:bg-[#e6f0fa] transition-colors"
                    >
                        {getTextTitle(text.id)}
                    </button>
                ))}
            </div>
        </div>
    );
}
